@@ -8,19 +8,19 @@ from wikipedia_tools.utils import properties
 
 @dataclasses.dataclass
 class WikipediaRevisionAnalyzer:
-    categories : list
-    revisions_from : str = "01.01.2001"
-    revisions_to : 'str|None' = None
+    categories: list
+    revisions_from: str = "01.01.2001"
+    revisions_to: "str|None" = None
     corpus: str = properties.CORPUS
-    download:bool = False
+    download: bool = False
 
     def __post_init__(self):
-        self.wikipages_revisions:pd.DataFrame = self.load_data()
+        self.wikipages_revisions: pd.DataFrame = self.load_data()
 
-
-
-    def get_edited_pages_count(self, period_type:str=""):
-        wikipedia_pages_per_category = processor.get_wikipedia_page_titles(categories = self.categories, corpus = self.corpus)
+    def get_edited_pages_count(self, period_type: str = ""):
+        wikipedia_pages_per_category = processor.get_wikipedia_page_titles(
+            categories=self.categories, corpus=self.corpus
+        )
         return
 
     def get_revisions_count(self):
@@ -33,4 +33,4 @@ class WikipediaRevisionAnalyzer:
         return
 
     def get_user_type_count(self):
-        return
\ No newline at end of file
+        return
